@@ -17,9 +17,10 @@
 #' @param spatialAutocorrelation strength of spatial Autocorrelation
 #' @param factorResponse should the response be transformed to a factor (inteded to be used for 0/1 data)
 #' @param replicates number of datasets to create
+#' @param hasNA should an NA be added to the environmental predictor (for test purposes)
 #' @export
 #' @example /inst/examples/createDataHelp.R
-createData <- function(sampleSize = 100, intercept = 0, fixedEffects = 1, quadraticFixedEffects = NULL, numGroups = 10, randomEffectVariance = 1, overdispersion = 0, family = poisson(), scale = 1, cor = 0, roundPoissonVariance = NULL,  pZeroInflation = 0, binomialTrials = 1, temporalAutocorrelation = 0, spatialAutocorrelation =0, factorResponse = F, replicates=1){
+createData <- function(sampleSize = 100, intercept = 0, fixedEffects = 1, quadraticFixedEffects = NULL, numGroups = 10, randomEffectVariance = 1, overdispersion = 0, family = poisson(), scale = 1, cor = 0, roundPoissonVariance = NULL,  pZeroInflation = 0, binomialTrials = 1, temporalAutocorrelation = 0, spatialAutocorrelation =0, factorResponse = F, replicates=1, hasNA = F){
 
   nPredictors = length(fixedEffects)
 
@@ -124,7 +125,7 @@ createData <- function(sampleSize = 100, intercept = 0, fixedEffects = 1, quadra
       observedResponse = observedResponse * artificialZeros
     }
 
-    
+
     if(factorResponse) observedResponse = factor(observedResponse)
 
     # add spatialError?
@@ -132,6 +133,9 @@ createData <- function(sampleSize = 100, intercept = 0, fixedEffects = 1, quadra
     out[[i]] <- data.frame(ID = 1:sampleSize, observedResponse, predictors, group = as.factor(group), time, x, y)
   }
   if(length(out) == 1) out = out[[1]]
+
+  if(hasNA) out[1,3] = NA
+
   return(out)
 }
 #createData()
