@@ -1,33 +1,34 @@
 #' DHARMa standard residual plots
 #'
-#' This function creates standard plots for the simulated residuals
-#' @param x an object with simulated residuals created by \code{\link{simulateResiduals}}
-#' @param rank if T (default), the values of pred will be rank transformed. This will usually make patterns easier to spot visually, especially if the distribution of the predictor is skewed.
-#' @param ... further options for \code{\link{plotResiduals}}. Consider in particular parameters quantreg, rank and asFactor. xlab, ylab and main cannot be changed when using plotSimulatedResiduals, but can be changed when using plotResiduals.
-#' @details The function creates two plots. To the left, a qq-uniform plot to detect deviations from overall uniformity of the residuals (calling \code{\link{plotQQunif}}), and to the right, a plot of residuals against predicted values (calling \code{\link{plotResiduals}}). Outliers are highlighted in red (for more on outliers, see \code{\link{testOutliers}}). For a correctly specified model, we would expect
+#' This S3 function creates standard plots for the simulated residuals contained in an object of class DHARMa, using \code{\link{plotQQunif}} (left panel) and \code{\link{plotResiduals}} (right panel)
+#' 
+#' @param x an object of class DHARMa with simulated residuals created by \code{\link{simulateResiduals}}
+#' @param ... further options for \code{\link{plotResiduals}}. Consider in particular parameters quantreg, rank and asFactor. xlab, ylab and main cannot be changed when using plot.DHARMa, but can be changed when using plotResiduals.
+#' 
+#' @details The function creates a plot with two panels. The left panel is a uniform qq plot (calling \code{\link{plotQQunif}}), and the right panel shows residuals against predicted values (calling \code{\link{plotResiduals}}), with outliers highlighted in red. 
+#' 
+#' Very briefly, we would expect that a correctly specified model shows:
 #'
-#' a) a straight 1-1 line in the uniform qq-plot -> evidence for an overall uniform (flat) distribution of the residuals
+#' a) a straight 1-1 line, as well as n.s. of the displayed tests in the qq-plot (left) -> evidence for an the correct overall residual distribution (for more details on the interpretation of this plot, see \code{\link{plotQQunif}})
 #'
-#' b) uniformity of residuals in the vertical direction in the res against predictor plot
+#' b) visual homogeneity of residuals in both vertical and horizontal direction, as well as n.s. of quantile tests in the res ~ predictor plot (for more details on the interpretation of this plot, see \code{\link{plotResiduals}})
 #'
-#' Deviations of this can be interpreted as for a linear regression. See the vignette for detailed examples.
-#'
-#' To provide a visual aid in detecting deviations from uniformity in y-direction, the plot of the residuals against the predicted values also performs an (optional) quantile regression, which provides 0.25, 0.5 and 0.75 quantile lines across the plots. These lines should be straight, horizontal, and at y-values of 0.25, 0.5 and 0.75. Note, however, that some deviations from this are to be expected by chance, even for a perfect model, especially if the sample size is small. See further comments on this plot, its interpretation and options, in \code{\link{plotResiduals}}
-#'
-#' The quantile regression can take some time to calculate, especially for larger datasets. For that reason, quantreg = F can be set to produce a smooth spline instead. This is default for n > 2000.
+#' Deviations from these expectations can be interpreted similar to a linear regression. See the vignette for detailed examples.
+#' 
+#' Note that, unlike \code{\link{plotResiduals}}, plot.DHARMa command uses the default rank = T.
 #'
 #' @seealso \code{\link{plotResiduals}}, \code{\link{plotQQunif}}
 #' @example inst/examples/plotsHelp.R
 #' @import graphics
 #' @import utils
 #' @export
-plot.DHARMa <- function(x, rank = TRUE, ...){
+plot.DHARMa <- function(x, ...){
 
   oldpar <- par(mfrow = c(1,2), oma = c(0,1,2,1))
   on.exit(par(oldpar))
 
   plotQQunif(x)
-  plotResiduals(x, rank = rank, ...)
+  plotResiduals(x, ...)
 
   mtext("DHARMa residual diagnostics", outer = T)
 }
@@ -91,7 +92,7 @@ plotSimulatedResiduals <- function(simulationOutput, ...){
 #' @param testDispersion if T, the function \code{\link{testDispersion}} will be called and the result will be added to the plot
 #' @param ... arguments to be passed on to \code{\link[gap]{qqunif}}
 #'
-#' @details the function calls qqunif from the R package gap to create a quantile-quantile plot for a uniform distribution.
+#' @details the function calls qqunif from the R package gap to create a quantile-quantile plot for a uniform distribution, and overlays tests for particular distributional problems as specified.
 #' @seealso \code{\link{plotSimulatedResiduals}}, \code{\link{plotResiduals}}
 #' @example inst/examples/plotsHelp.R
 #' @export
@@ -103,28 +104,28 @@ plotQQunif <- function(simulationOutput, testUniformity = T, testOutliers = T, t
 
   if(testUniformity == TRUE){
     temp = testUniformity(simulationOutput, plot = F)
-    legend("topleft", c(paste("KS test: p=", round(temp$p.value, digits = 5)), paste("Deviation ", ifelse(temp$p.value < 0.05, "significant", "n.s."))), text.col = ifelse(temp$p.value < 0.05, "red", "black" ), bty="n")
+    legend("topleft", 
+           c(paste("KS test: p=", round(temp$p.value, digits = 5)), 
+             paste("Deviation ", ifelse(temp$p.value < 0.05, "significant", "n.s."))), 
+           text.col = ifelse(temp$p.value < 0.05, "red", "black" ), bty="n")
+    
   }
 
   if(testOutliers == TRUE){
+    temp = testOutliers(simulationOutput, plot = F)
+    legend("bottomright", 
+           c(paste("Outlier test: p=", round(temp$p.value, digits = 5)), 
+             paste("Deviation ", ifelse(temp$p.value < 0.05, "significant", "n.s."))),
+           text.col = ifelse(temp$p.value < 0.05, "red", "black" ), bty="n")
     
-    check = FALSE
-    if(simulationOutput$integerResponse == FALSE) useMethod = "binomial"
-    else{
-      if(simulationOutput$nObs > 500){
-        useMethod = "binomial"
-        check = TRUE
-      } else useMethod = "bootstrap"
-    }
-    temp = testOutliers(simulationOutput, type =  useMethod, plot = F)
-    
-    if (temp$p.value < 0.05 & check == T) message("DHARMa:plot used testOutliers with type = binomial for computational reasons (nObs > 500). Note that this method may not have inflated Type I error rates for integer-valued distributions. To get a more exact result, it is recommended to re-run testOutliers with type = 'bootstrap'. See ?testOutliers for details")
-    legend("bottomright", c(paste("Outlier test: p=", round(temp$p.value, digits = 5)), paste("Deviation ", ifelse(temp$p.value < 0.05, "significant", "n.s."))), text.col = ifelse(temp$p.value < 0.05, "red", "black" ), bty="n")
   }
 
   if(testDispersion == TRUE){
     temp = testDispersion(simulationOutput, plot = F)
-    legend("center", c(paste("Dispersion test: p=", round(temp$p.value, digits = 5)), paste("Deviation ", ifelse(temp$p.value < 0.05, "significant", "n.s."))), text.col = ifelse(temp$p.value < 0.05, "red", "black" ), bty="n")
+    legend("center", 
+           c(paste("Dispersion test: p=", round(temp$p.value, digits = 5)), 
+             paste("Deviation ", ifelse(temp$p.value < 0.05, "significant", "n.s."))), 
+           text.col = ifelse(temp$p.value < 0.05, "red", "black" ), bty="n")
   }
 
 }
@@ -137,7 +138,7 @@ plotQQunif <- function(simulationOutput, testUniformity = T, testOutliers = T, t
 #'
 #' @param simulationOutput on object, usually a DHARMa object, from which residual values can be extracted. Alternatively, a vector with residuals or a fitted model can be provided, which will then be transformed into a DHARMa object.
 #' @param form optional predictor against which the residuals should be plotted. Default is to used the predicted(simulationOutput)
-#' @param quantreg whether to perform a quantile regression on 0.25, 0.5, 0.75 on the residuals. If F, a spline will be created instead. Default NULL chooses T for nObs < 2000, and F otherwise.
+#' @param quantreg whether to perform a quantile regression based on \code{\link{testQuantiles}} or a smooth spline around the mean. Default NULL chooses T for nObs < 2000, and F otherwise.
 #' @param rank if T, the values provided in form will be rank transformed. This will usually make patterns easier to spot visually, especially if the distribution of the predictor is skewed. If form is a factor, this has no effect.
 #' @param asFactor should a numeric predictor provided in form be treated as a factor. Default is to choose this for < 10 unique values, as long as enough predictions are available to draw a boxplot.
 #' @param smoothScatter if T, a smooth scatter plot will plotted instead of a normal scatter plot. This makes sense when the number of residuals is very large. Default NULL chooses T for nObs < 10000, and F otherwise.
@@ -147,25 +148,24 @@ plotQQunif <- function(simulationOutput, testUniformity = T, testOutliers = T, t
 #'
 #' Outliers are highlighted in red (for information on definition and interpretation of outliers, see \code{\link{testOutliers}}).
 #'
-#' To provide a visual aid in detecting deviations from uniformity in y-direction, the plot function calculates an (optional) quantile regression, which compares the empirical 0.25, 0.5 and 0.75 quantiles (default) in y direction (red solid lines) with the theoretical 0.25, 0.5 and 0.75 quantiles (dashed black line).
-#'
-#' Asymptotically (i.e. for lots of data / residuals), if the model is correct, theoretical and the empirical quantiles should be identical (i.e. dashed and solid lines should match). A p-value for the deviation is calculated for each quantile line. Significant deviations are highlighted by red color.
-#'
-#' If form is a factor, a boxplot will be plotted instead of a scatter plot. The distribution for each factor level should be uniformly distributed, so the box should go from 0.25 to 0.75, with the median line at 0.5. Again, chance deviations from this will increases when the sample size is smaller. You can run null simulations to test if the deviations you see exceed what you would expect from random variation. If you want to create box plots for categorical predictors (e.g. because you only have a small number of unique numeric predictor values), you can convert your predictor with as.factor(pred)
+#' To provide a visual aid in detecting deviations from uniformity in y-direction, the plot function calculates an (optional) quantile regression of the residuals, by default for the 0.25, 0.5 and 0.75 quantiles. As the residuals should be uniformly distributed for a correctly specified model, the theoretical expectations for these regressions are straight lines at 0.25, 0.5 and 0.75, which are displayed as dashed black lines on the plot. Some deviations from these expectations are to be expected by chance, however, even for a perfect model, especially if the sample size is small. The function therefore tests if deviation of the fitted quantile regression from the expectation is significant, using  \code{\link{testQuantiles}}. If so, the significant quantile regression will be highlighted as red, and a warning will be displayed in the plot. 
+#' 
+#' The quantile regression can take some time to calculate, especially for larger datasets. For that reason, quantreg = F can be set to produce a smooth spline instead. This is default for n > 2000.
+#' 
+#' If form is a factor, a boxplot will be plotted instead of a scatter plot. The distribution for each factor level should be uniformly distributed, so the box should go from 0.25 to 0.75, with the median line at 0.5 (within-group ). To test if deviations from those expecations are significant, KS-tests per group and a Levene test for homogeneity of variances is performed. See \code{\link{testCategorical}} for details. 
+#' 
+#' @note if nObs > 10000, the scatter plot is replaced by graphics::smoothScatter
 #' 
 #' @return if quantile tests are performed, the function returns them invisibly.
 #'
-#' @note The quantile regression can take some time to calculate, especially for larger datasets. For that reason, quantreg = F can be set to produce a smooth spline instead.
-#'
-#' @seealso \code{\link{plotQQunif}}
+#' @seealso \code{\link{plotQQunif}}, \code{\link{testQuantiles}}, \code{\link{testOutliers}}
 #' @example inst/examples/plotsHelp.R
 #' @export
-plotResiduals <- function(simulationOutput, form = NULL, quantreg = NULL, rank = F, asFactor = NULL, smoothScatter = NULL, quantiles = c(0.25, 0.5, 0.75), ...){
+plotResiduals <- function(simulationOutput, form = NULL, quantreg = NULL, rank = T, asFactor = NULL, smoothScatter = NULL, quantiles = c(0.25, 0.5, 0.75), ...){
 
 
   ##### Checks #####
 
-
   a <- list(...)
   a$ylab = checkDots("ylab", "Standardized residual", ...)
   if(is.null(form)){
@@ -202,16 +202,21 @@ plotResiduals <- function(simulationOutput, form = NULL, quantreg = NULL, rank =
 
   blackcol = rgb(0,0,0, alpha = max(0.1, 1 - 3 * length(res) / switchScatter))
 
+  # Note to self: why is this wrapped in do.call?
+  # Answer: because of the check dots, needs to be consolidate, e.g. for testCategorical
 
   # categorical plot
   if(is.factor(pred)){
-    do.call(plot, append(list(res ~ pred, ylim = c(0,1), axes = FALSE), a))
+    testCategorical(simulationOutput = simulationOutput, catPred = pred, quantiles = quantiles)
   }
   # smooth scatter
   else if (smoothScatter == TRUE) {
     defaultCol = ifelse(res == 0 | res == 1, 2,blackcol)
     do.call(graphics::smoothScatter, append(list(x = pred, y = res , ylim = c(0,1), axes = FALSE, colramp = colorRampPalette(c("white", "darkgrey"))),a))
     points(pred[defaultCol == 2], res[defaultCol == 2], col = "red", cex = 0.5)
+    
+    axis(1)
+    axis(2, at=c(0, quantiles, 1))
   }
   # normal plot
   else{
@@ -220,11 +225,11 @@ plotResiduals <- function(simulationOutput, form = NULL, quantreg = NULL, rank =
     a$col = checkDots("col", defaultCol, ...)
     a$pch = checkDots("pch", defaultPch, ...)
     do.call(plot, append(list(res ~ pred, ylim = c(0,1), axes = FALSE), a))
+    
+    axis(1)
+    axis(2, at=c(0, quantiles, 1))
   }
 
-  axis(1)
-  axis(2, at=c(0, 0.25, 0.5, 0.75, 1))
-
   ##### Quantile regressions #####
 
   main = checkDots("main", "Residual vs. predicted", ...)
@@ -233,7 +238,7 @@ plotResiduals <- function(simulationOutput, form = NULL, quantreg = NULL, rank =
   if(is.numeric(pred)){
     if(quantreg == F){
       title(main = main, cex.main = 1)
-      abline(h = c(0.25, 0.5, 0.75), col = "black", lwd = 0.5, lty = 2)
+      abline(h = quantiles, col = "black", lwd = 0.5, lty = 2)
       try({
         lines(smooth.spline(pred, res, df = 10), lty = 2, lwd = 2, col = "red")
         abline(h = 0.5, col = "red", lwd = 2)
@@ -293,6 +298,12 @@ ensurePredictor <- function(simulationOutput,
   if(!is.null(predictor)){
 
     if(length(predictor) != length(simulationOutput$scaledResiduals)) stop("DHARMa: residuals and predictor do not have the same length. The issue is possibly that you have NAs in your predictor that were removed during the model fit. Remove the NA values from your predictor.")
+    
+    if(is.character(predictor)) {
+      predictor = factor(predictor)
+      warning("DHARMa:::ensurePredictor: character string was provided as predictor. DHARMa has converted to factor automatically. To remove this warning, please convert to factor before attempting to plot with DHARMa.")
+    }
+    
   } else {
 
     predictor = simulationOutput$fittedPredictedResponse
